@@ -49,7 +49,7 @@ class AblationCAM(BaseCAM):
 
     def assemble_ablation_scores(self,
                                  new_scores: list,
-                                 original_score: float ,
+                                 original_score: float,
                                  ablated_channels: np.ndarray,
                                  number_of_channels: int) -> np.ndarray:
         """ Take the value from the channels that were ablated,
@@ -77,16 +77,19 @@ class AblationCAM(BaseCAM):
                         targets: List[Callable],
                         activations: torch.Tensor,
                         grads: torch.Tensor) -> np.ndarray:
-        
-        # Do a forward pass, compute the target scores, and cache the activations
+
+        # Do a forward pass, compute the target scores, and cache the
+        # activations
         handle = target_layer.register_forward_hook(self.save_activation)
         with torch.no_grad():
             outputs = self.model(input_tensor)
             handle.remove()
-            original_scores = np.float32([target(output).cpu().item() for target, output in zip(targets, outputs)])
+            original_scores = np.float32(
+                [target(output).cpu().item() for target, output in zip(targets, outputs)])
 
         # Replace the layer with the ablation layer.
-        # When we finish, we will replace it back, so the original model is unchanged.
+        # When we finish, we will replace it back, so the original model is
+        # unchanged.
         ablation_layer = self.ablation_layer
         replace_layer_recursive(self.model, target_layer, ablation_layer)
 
@@ -95,33 +98,44 @@ class AblationCAM(BaseCAM):
         # This is a "gradient free" method, so we don't need gradients here.
         with torch.no_grad():
             # Loop over each of the batch images and ablate activations for it.
-            for batch_index, (target, tensor) in enumerate(zip(targets, input_tensor)):
+            for batch_index, (target, tensor) in enumerate(
+                    zip(targets, input_tensor)):
                 new_scores = []
                 batch_tensor = tensor.repeat(self.batch_size, 1, 1, 1)
 
                 # Check which channels should be ablated. Normally this will be all channels,
-                # But we can also try to speed this up by using a low ratio_channels_to_ablate.
-                channels_to_ablate = ablation_layer.activations_to_be_ablated(activations[batch_index, :],
-                                                                              self.ratio_channels_to_ablate)
+                # But we can also try to speed this up by using a low
+                # ratio_channels_to_ablate.
+                channels_to_ablate = ablation_layer.activations_to_be_ablated(
+                    activations[batch_index, :], self.ratio_channels_to_ablate)
                 number_channels_to_ablate = len(channels_to_ablate)
 
-                for i in tqdm.tqdm(range(0, number_channels_to_ablate, self.batch_size)):
+                for i in tqdm.tqdm(
+                    range(
+                        0,
+                        number_channels_to_ablate,
+                        self.batch_size)):
                     if i + self.batch_size > number_channels_to_ablate:
-                        batch_tensor = batch_tensor[:(number_channels_to_ablate - i)]
+                        batch_tensor = batch_tensor[:(
+                            number_channels_to_ablate - i)]
 
                     # Change the state of the ablation layer so it ablates the next channels.
                     # TBD: Move this into the ablation layer forward pass.
-                    ablation_layer.set_next_batch(input_batch_index=batch_index,
-                                                  activations=self.activations,
-                                                  num_channels_to_ablate=batch_tensor.size(0))
-                    score = [target(o).cpu().item() for o in self.model(batch_tensor)]
+                    ablation_layer.set_next_batch(
+                        input_batch_index=batch_index,
+                        activations=self.activations,
+                        num_channels_to_ablate=batch_tensor.size(0))
+                    score = [target(o).cpu().item()
+                             for o in self.model(batch_tensor)]
                     new_scores.extend(score)
-                    ablation_layer.indices = ablation_layer.indices[batch_tensor.size(0):]
+                    ablation_layer.indices = ablation_layer.indices[batch_tensor.size(
+                        0):]
 
-                new_scores = self.assemble_ablation_scores(new_scores,
-                                                           original_scores[batch_index],
-                                                           channels_to_ablate,
-                                                           number_of_channels)
+                new_scores = self.assemble_ablation_scores(
+                    new_scores,
+                    original_scores[batch_index],
+                    channels_to_ablate,
+                    number_of_channels)
                 weights.extend(new_scores)
 
         weights = np.float32(weights)
